@@ -10,6 +10,6 @@ def get_model():
         Path to file.
 
     """
-    with resources.path(__package__, "secrules.tx") as f:
+    with resources.path("secrules_parsing.model", "secrules.tx") as f:
         data_file_path = f
     return data_file_path
